==> openpyxl-2.0.2.tar.gz: openpyxl-2.0.2/openpyxl/cell/formula.py <==
from __future__ import absolute_import
# Copyright (c) 2010-2014 openpyxl
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# @license: http://www.opensource.org/licenses/mit-license.php
# @author: see AUTHORS file


"""
Handling Shared and Array Formulae
"""

class SharedFormula(object):

    __slots__ = ('range', 'key', 'expression')

    def __init__(self, range, key, expression):
        self.range = range
        self.key = key
        self.expression = expression

    def range(self):
        """Range of cells to which the formula applies"""

    def key(self):
        """Key"""

    def expression(self):
        """Expression"""


# Unpack expression?
# Value
# Return expression or information about shared formula?

# Creating - first incidence

if key not in ws.formula_attributes:
    shared = SharedFormula(range, key, expression)
    ws.formula_attributes[key] = shared
else:
    # expression already stored
    pass
cell.value = ws.formula_attributes[key].expression

==> openpyxl-2.1.5.tar.gz: openpyxl-2.1.5/openpyxl/cell/formula.py <==
from __future__ import absolute_import
# Copyright (c) 2010-2015 openpyxl
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# @license: http://www.opensource.org/licenses/mit-license.php
# @author: see AUTHORS file


"""
Handling Shared and Array Formulae
"""

class SharedFormula(object):

    #__slots__ = ('range', 'key', 'expression')

    def __init__(self, range, key, expression):
        self.range = range
        self.key = key
        self.expression = expression

    def range(self):
        """Range of cells to which the formula applies"""

    def key(self):
        """Key"""

    def expression(self):
        """Expression"""


# Unpack expression?
# Value
# Return expression or information about shared formula?

# Creating - first incidence


if __name__ == "__main__":

    if 'key' not in ws.formula_attributes:
        shared = SharedFormula(range, key, expression)
        ws.formula_attributes[key] = shared
    else:
        # expression already stored
        pass
    cell.value = ws.formula_attributes[key].expression
